--only enable when player is druid
local _, class = UnitClass("player");
if (class ~= "DRUID") then
	return
end;

--setup locals
local DummyNewAllButton, DummyNewOneButton, DummyOldAllButton, DummyOldOneButton;

--hides old buttons, shows/hides new buttons
local function ToggleCraftButtons()
	if not UnitAffectingCombat("player") then
		--hide old buttons
		DummyOldAllButton:Hide();
		DummyOldOneButton:Hide();

		--lets look if our buttons should be visible
		local _, _, _, _, altVerb = GetTradeSkillInfo(GetTradeSkillSelectionIndex());
		if IsTradeSkillLinked() or IsTradeSkillGuild() then
			--hide new buttons
			DummyNewOneButton:Hide();
			DummyNewAllButton:Hide();
		elseif altVerb then
			--selected item is not craftable, so the (new) "craft all" button should not be visible
			DummyNewAllButton:Hide();
			DummyNewOneButton:Show();
		else
			--show new buttons
			DummyNewOneButton:Show();
			DummyNewAllButton:Show();
		end

		--bug fix, so that our buttons wont "vanish" behind the tradeskillframe
		if (DummyNewOneButton:IsVisible()) then
			if (DummyNewOneButton:GetFrameLevel() <= TradeSkillFrame:GetFrameLevel()) then
				DummyNewOneButton:SetFrameLevel(TradeSkillFrame:GetFrameLevel()+1);
			end;
		end;
		if (DummyNewAllButton:IsVisible()) then
			if (DummyNewAllButton:GetFrameLevel() <= TradeSkillFrame:GetFrameLevel()) then
				DummyNewAllButton:SetFrameLevel(TradeSkillFrame:GetFrameLevel()+1);
			end;
		end;
	end
end

--hooks click events in the tradeskill window
local function HookMyStuffToTradeWindow(buttonId)
	buttonId:HookScript("OnClick",function(...)
		ToggleCraftButtons();
	end);
	--hooksecurefunc(buttonId,"Click",ToggleCraftButtons);
end


--creates new buttons
local function ReplaceButton(oldButtonlink)
	if oldButtonlink then
		--create new button with the SecureActionButtonTemplate, which we use to do our protected stuff
		local OldButton, NewButton = oldButtonlink, CreateFrame("Button",oldButtonlink:GetName(),oldButtonlink:GetParent(),"SecureActionButtonTemplate, MagicButtonTemplate");

		--steal position and script handler from the old button
		NewButton:SetAllPoints(OldButton);
		NewButton:HookScript("OnClick",OldButton:GetScript("OnClick"));

		--set attributes to run a macro which does our protected stuff
		NewButton:SetAttribute("type","macro");
		NewButton:SetAttribute("macrotext","/cancelform");
		return NewButton;
	end
	--credits to SDPhantom for help with this function
end;


--do our stuff:
local ProfessionOpenedFrame = CreateFrame("Frame");
ProfessionOpenedFrame:RegisterEvent("TRADE_SKILL_SHOW");
ProfessionOpenedFrame:SetScript("OnEvent",function(...)
	--initialize our stuff when trade skill window is opened
	if (not IsTradeSkillLinked()) and (not IsTradeSkillGuild()) and (TradeSkillCreateButton) and (TradeSkillCreateAllButton) and (not UnitAffectingCombat("player")) then		
		--save label of old buttons
		local ButtonTextOne, ButtonTextAll = TradeSkillCreateButton:GetText(), TradeSkillCreateAllButton:GetText();

		--save old buttons
		DummyOldOneButton, DummyOldAllButton  = TradeSkillCreateButton, TradeSkillCreateAllButton;

		--create new buttons
		DummyNewOneButton = ReplaceButton(TradeSkillCreateButton);
		DummyNewAllButton = ReplaceButton(TradeSkillCreateAllButton);

		--use saved labels for new buttons
		DummyNewOneButton:SetText(ButtonTextOne);
		DummyNewAllButton:SetText(ButtonTextAll);

		--overwrite globals
		TradeSkillCreateButton, TradeSkillCreateAllButton = DummyNewOneButton, DummyNewAllButton;

		--hook click events in the tradeskill window
		HookMyStuffToTradeWindow(TradeSkillSkill1);
		HookMyStuffToTradeWindow(TradeSkillSkill2);
		HookMyStuffToTradeWindow(TradeSkillSkill3);
		HookMyStuffToTradeWindow(TradeSkillSkill4);
		HookMyStuffToTradeWindow(TradeSkillSkill5);
		HookMyStuffToTradeWindow(TradeSkillSkill6);
		HookMyStuffToTradeWindow(TradeSkillSkill7);
		HookMyStuffToTradeWindow(TradeSkillSkill8);

		--hide old buttons, show/hide new buttons
		ToggleCraftButtons();

		--we are done
		ProfessionOpenedFrame:UnregisterAllEvents();
	elseif UnitAffectingCombat("player") then
		if (GetLocale() == "deDE") then
			print("CancelFormForCrafting: Konnte das Addon nicht aktivieren weil du im Kampf bist. Um das Addon zu aktivieren, oeffne ein Beruf-Fenster sobald du nicht mehr im Kampf bist.");
		else
			print("CancelFormForCrafting: Could not enable addon because you are infight. To enable the addon reopen a profession window when out of combat.");
		end
	end
end);